@@ -117,12 +117,6 @@ def parse_args(args):
         action="store_true",
         default=False,
         help="generate Tox configuration file")
-    parser.add_argument(
-        "--with-numpydoc",
-        dest="numpydoc",
-        action="store_true",
-        default=False,
-        help="add numpydoc to Sphinx configuration file")
 
     version = pyscaffold.__version__
     parser.add_argument('-v',
@@ -167,15 +161,18 @@ def get_default_opts(project_name, **aux_opts):
     classifiers = ['Development Status :: 4 - Beta',
                    'Programming Language :: Python']
     opts.setdefault('classifiers', utils.list2str(
-        classifiers, indent=14, brackets=False, quotes=False))
+        classifiers, indent=4, brackets=False, quotes=False, sep=''))
     opts.setdefault('url', 'http://...')
     # Initialize empty list of all requirements
     opts.setdefault('requirements', list())
     opts['namespace'] = utils.prepare_namespace(opts['namespace'])
     if opts['namespace']:
         opts['root_pkg'] = opts['namespace'][0]
+        opts['namespace_pkg'] = ".".join([opts['namespace'][-1],
+                                          opts['package']])
     else:
         opts['root_pkg'] = opts['package']
+        opts['namespace_pkg'] = opts['package']
     if opts['update']:
         if not os.path.exists(project_name):
             raise RuntimeError(
@@ -238,8 +235,8 @@ def main(args):
     """
     utils.check_setuptools_version()
     opts = parse_args(args)
-    opts = get_default_opts(opts['project'], **opts)
     make_sanity_checks(opts)
+    opts = get_default_opts(opts['project'], **opts)
     create_project(opts)
     if opts['update'] and not opts['force']:
         note = "Update accomplished!\n" \
